coloredfloateditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# coloredfloateditor

class `camelot.view.controls.editors.coloredfloateditor.` `ColoredFloatEditor`(parent, precision=2, reverse=False, neutral=False, option=None, field_name='float', **kwargs)

  Widget for editing a float field, with a calculator

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus